# eConEXG
## SDK for Niantong devices.

[![PyPI version](https://img.shields.io/pypi/v/econexg.svg)](https://pypi.org/project/econexg/)
[![PyPI Downloads](https://img.shields.io/pypi/dm/econexg.svg?label=Downloads)](
https://pypi.org/project/econexg/)
[![image](https://img.shields.io/pypi/l/econexg.svg)](https://github.com/niantong-intelligence/econexg/blob/main/LICENSE)
[![Rye](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/rye/main/artwork/badge.json)](https://rye.astral.sh/)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)

<!-- [![image](https://img.shields.io/pypi/pyversions/econexg.svg)](https://pypi.python.org/pypi/econexg) -->

For more information, see the online [documentation](https://niantong-intelligence.github.io/eConEXG/).
<!-- released start -->

## Installation

`pip install econexg`


Optional dependencies can be installed via `pip install econexg[option1,option2,...]`

    Available options:
        bdf: save to BDF file functionality support.
        lsl: LSL stream functionality support.
        wifi: iRecorder W32 wifi model support, msvc build tools required.

## Quick Start

Example code can be found in [examples](https://github.com/Niantong-Intelligence/eConEXG/tree/main/examples).

## Platform Support
| Hardware| Windows| macOS | Linux  |
|:----|:---------:|:--------:|:------:|
| iRecorder USB |✓|✓|✓|
| iRecorder W8\|16|✓|𐄂|𐄂|
| iRecorder W32 |✓|✓|✓|
| iFocus        |✓|✓|✓|
| TriggerBox    |✓|✓|✓|


## More

* [Discussion Forum](https://github.com/Niantong-Intelligence/eConEXG/discussions), to discuss the project
  on GitHub
* [Issue Tracker](https://github.com/Niantong-Intelligence/eConEXG/issues), if you run into bugs or have suggestions
